%define _prefix /scisoft
%define _bindir %{_prefix}/bin
%define module guiapps

# Since IRAF is an externally built binary, we do not bother with preparing
# debug packages for its external addon modules either.
%define debug_package %{nil}

Name:           scisoft-iraf-guiapps
Version:        2013.10.28
Release:        1%{?dist}
Summary:        Prototype IRAF GUI applications
Distribution:   Scisoft
Group:          Applications/Scientific
License:        Distributable
URL:            http://iraf.noao.edu/projects/guiapps
Source0:        ftp://iraf.noao.edu/iraf/extern-v216/%{module}-src.tar.gz
Source1:        ftp://iraf.noao.edu/iraf/extern-v216/%{module}.readme

BuildRequires:  /usr/bin/tee
BuildRequires:  /usr/bin/cat
BuildRequires:  /usr/bin/grep
BuildRequires:  sudo
BuildRequires:  scisoft-common
BuildRequires:  scisoft-iraf
Requires:       scisoft-iraf
AutoReq:        no

%description
Some time ago we started a project to develop prototype IRAF applications with
integral GUIs (graphical user interfaces). These applications have long since
served their purpose in prototyping new technology for science GUIs and
component-based applications in IRAF. The GUI prototypes are much more than just
technology prototypes however: these are very useful science applications with
many new features, with a nice graphical user interface to boot. With the
release of IRAF V2.11.3 and X11IRAF V1.2 earlier this year (including the latest
hooks needed to run IRAF GUI applications) it became possible to wrap up work on
the GUI prototypes and get them out for people to use.

The prototype GUI applications are included in the package GUIAPPS. IRAF V2.11.3
or later and the X11IRAF V1.2 version of xgterm is required (see /iraf/x11iraf
on this ftp archive) to run the GUI applications correctly (various bugs will be
present if you use an older version, but most things will still work). Test
data, tutorials, and documentation is provided for all these applications to
make them as easy to use as possible. Please give them a try.

%prep
%setup -q -n %{module}

%build
# IRAF does not provide an easy to use build procedure that will allow building
# external packages within a build directory and installing it into the
# buildroot for packaging. Therefore we are forced to rely on the user to have
# sudo rights, to prepare the files directly in /scisoft.
sudo install -m 755 -d %{_datadir}/iraf/extern
sudo cp -r %{_builddir}/%{module} %{_datadir}/iraf/extern/%{module}
cat <<EOF | sudo /bin/sh 2>&1 | tee %{_builddir}/iraf_pkg_build.log
export PATH="%{_bindir}:$PATH"
export iraf=%{_datadir}/iraf/iraf/
%if %{_arch} == x86_64
export IRAFARCH=linux64
%else
export IRAFARCH=linux
%endif
%{_bindir}/iraf_pkg.sh --source %{module}
EOF
# Check for errors from mkpkg to avoid silent build failures.
# iraf_pkg.sh always returns zero, since the IRAF cl command does not appear to
# have a sane mechanism to capture error status.
if grep 'returned error' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi
if grep '[[:alpha:]]*cc: error:' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi
if grep 'No such file or directory' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi
if grep 'error while loading' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi
if grep 'error during checkin' %{_builddir}/iraf_pkg_build.log > /dev/null ; then
    exit 1
fi

%install
install -m 755 -d %{buildroot}%{_datadir}/iraf/extern
cp -r %{_datadir}/iraf/extern/%{module} %{buildroot}%{_datadir}/iraf/extern/%{module}
install -m 755 -d %{buildroot}%{_docdir}/%{module}
install -m 644 %{SOURCE1} %{buildroot}%{_docdir}/%{module}/

%clean
# Cleaning up since an inplace build was performed with sudo.
sudo %{_bindir}/iraf_pkg.sh --remove %{module}
sudo rm -rf %{_datadir}/iraf/extern/%{module}
sudo rmdir --ignore-fail-on-non-empty %{_datadir}/iraf/extern

%files
%docdir %{_docdir}/%{module}
%{_prefix}
%defattr(-,root,root,-)

# Edit the extern.pkg file the first time and remove it the last time.

%post
# argument=1 -> this is the first time it is installed (no updates)
if [ "$*" = 1 ]; then
  %{_bindir}/iraf_pkg.sh --edit %{module} >/dev/null 2>&1
fi

%postun
# argument=0 -> this is the last time it is de-installed (no updates)
if [ "$*" = 0 ]; then
  %{_bindir}/iraf_pkg.sh --remove %{module} >/dev/null 2>&1
fi

%changelog
* Mon Mar 5 2018 Artur Szostak <aszostak@partner.eso.org>
- Integrating module into automated build system for Scisoft.

* Fri Oct 18 2013 Carlos Guirao
- Integration for scisoft 8
